@@ -1,12 +1,11 @@
 # Copyright 2024 CrackNuts. All rights reserved.
 
-__version__ = "0.15.1"
+__version__ = "0.19.2"
 
 import sys
 import typing
 from collections.abc import Callable
 
-from cracknuts import jupyter
 from cracknuts.acquisition import Acquisition, AcquisitionBuilder
 from cracknuts.cracker.cracker_basic import CrackerBasic
 from cracknuts.cracker.cracker_g1 import CrackerG1
@@ -17,8 +16,11 @@ try:
 
     if "ipykernel" not in sys.modules:
         display = None
+    else:
+        from cracknuts import jupyter as cn_jupyter
 except ImportError:
     display = None
+    cn_jupyter = None
 
 
 def version():
@@ -57,36 +59,48 @@ def new_cracker(
 def new_acquisition(
     cracker: CrackerBasic,
     init: Callable[[CrackerBasic], None] | None = None,
-    do: Callable[[CrackerBasic], None] | None = None,
+    do: Callable[[CrackerBasic], dict[str, bytes]] | None = None,
+    finish: Callable[[CrackerBasic], None] | None = None,
+    sample_length: int | None = None,
+    data_plaintext_length: int | None = None,
+    data_ciphertext_length: int | None = None,
+    data_key_length: int | None = None,
+    data_extended_length: int | None = None,
+    **acq_kwargs,
 ) -> Acquisition:
-    return AcquisitionBuilder().cracker(cracker).init(init).do(do).build()
+    acq_kwargs["sample_length"] = sample_length
+    acq_kwargs["data_plaintext_length"] = data_plaintext_length
+    acq_kwargs["data_ciphertext_length"] = data_ciphertext_length
+    acq_kwargs["data_key_length"] = data_key_length
+    acq_kwargs["data_extended_length"] = data_extended_length
+    return AcquisitionBuilder().cracker(cracker).init(init).do(do).finish(finish).build(**acq_kwargs)
 
 
 if display is not None:
 
     def panel(acq: Acquisition):
-        return jupyter.display_cracknuts_panel(acq)
+        return cn_jupyter.display_cracknuts_panel(acq)
 
 
 if display is not None:
 
     def panel_cracker(cracker: CrackerBasic):
-        return jupyter.display_cracker_panel(cracker)
+        return cn_jupyter.display_cracker_panel(cracker)
 
 
 if display is not None:
 
     def panel_scope(acq: Acquisition):
-        return jupyter.display_scope_panel(acq)
+        return cn_jupyter.display_scope_panel(acq)
 
 
 if display is not None:
 
     def panel_acquisition(acq: Acquisition):
-        return jupyter.display_acquisition_panel(acq)
+        return cn_jupyter.display_acquisition_panel(acq)
 
 
 if display is not None:
 
     def panel_trace():
-        return jupyter.display_trace_panel()
+        return cn_jupyter.display_trace_panel()
